@@ -290,11 +290,14 @@ pub async fn next_message(
             let mut length_buf = Buffer::from(peak[2..4].to_vec());
             let length = length_buf.read_u16().unwrap();
             //@handle ex message here.
-            let mut buffer = Buffer::from(&peak[0..length as usize]);
+            let mut buf = vec![0u8; length as usize];
+            stream.read_exact(&mut buf).await?;
+            // let mut buffer = Buffer::from(&peak[0..length as usize]);
+            let mut buffer = Buffer::from(buf);
             //@todo I think we need a consume here... But we need to be very careful about this
             //placement.
-            stream.consume_unpin(buffer.len());
-            debug!("{:?}", buffer);
+            // stream.consume_unpin(buffer.len());
+            // debug!("{:?}", buffer);
 
             let ex_message = ExMessageGeneric::from_buffer(&mut buffer)?;
             return Ok((
